kozinak
=======

.. image:: https://img.shields.io/pypi/v/kozinak.svg
    :target: https://pypi.python.org/pypi/kozinak
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/aleksejkozin/kozinak.png
   :target: https://travis-ci.org/aleksejkozin/kozinak
   :alt: Latest Travis CI build status

My python tools

Authors
-------

`kozinak` was written by `Aleksey Kozin <cirnotoss@gmail.com>`_.
